"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultAccountUIReducer = void 0;

var _state = require("./state");

var _TransitState = require("../TransitState");

/**
 * @packageDocumentation
 * @module AccountUIContext
 */

/**
 * Default reducer for global [[AccountUIState]].
 *
 * @param prevState Previous [[AccountUIState]] to update.
 * @param action State change action, which should be of type [[AccountActions]].
 */
const defaultAccountUIReducer = (prevState, action) => {
  switch (action.type) {
    // Login
    case 'Authentication/Login/Started':
      return { ...prevState,
        login: { ...(0, _TransitState.transitStart)(),
          email: action.payload.email
        },
        isLogOut: false,
        email: action.payload.email
      };

    case 'Authentication/Login/Succeeded':
      return { ...prevState,
        login: { ...(0, _TransitState.transitSuccess)(),
          email: action.payload.email
        },
        isLogOut: false,
        email: action.payload.email
      };

    case 'Authentication/Login/Failed':
      return { ...prevState,
        login: { ...(0, _TransitState.transitFailed)(action.payload.errorMessage),
          email: action.payload.email
        },
        isLogOut: false,
        email: action.payload.email
      };

    case 'Authentication/Login/Reset':
      return { ..._state.initialAccountUIState
      };
    // Logout

    case 'Authentication/Logout/Reset':
      return { ..._state.initialAccountUIState,
        isLogOut: true
      };
    // Reset Password ("forgot password" request)

    case 'Authentication/ResetPassword/Reset':
      return { ...prevState,
        forgotPassword: { ..._TransitState.initialTransitState,
          email: null
        }
      };

    case 'Authentication/ResetPassword/Started':
      return { ...prevState,
        forgotPassword: { ...(0, _TransitState.transitStart)(action.payload.transitId),
          email: action.payload.email
        }
      };

    case 'Authentication/ResetPassword/Succeeded':
      if (prevState.forgotPassword.transitId !== action.payload.transitId) {
        return prevState;
      }

      return { ...prevState,
        forgotPassword: { ...(0, _TransitState.transitSuccess)(action.payload.transitId),
          email: action.payload.email
        }
      };

    case 'Authentication/ResetPassword/Failed':
      if (prevState.forgotPassword.transitId !== action.payload.transitId) {
        return prevState;
      }

      return { ...prevState,
        forgotPassword: { ...(0, _TransitState.transitFailed)(action.payload.errorMessage, action.payload.transitId),
          email: action.payload.email
        }
      };
    // Verify code for reset password (code from "forgot password" email)

    case 'Authentication/VerifyResetCode/Reset':
      return { ...prevState,
        setPassword: { ...prevState.setPassword,
          verifyResetCodeTransit: _TransitState.initialTransitState
        }
      };

    case 'Authentication/VerifyResetCode/Started':
      return { ...prevState,
        setPassword: { ...prevState.setPassword,
          verifyResetCodeTransit: (0, _TransitState.transitStart)(action.payload.transitId)
        }
      };

    case 'Authentication/VerifyResetCode/Succeeded':
      if (prevState.setPassword.verifyResetCodeTransit.transitId !== action.payload.transitId) {
        return prevState;
      }

      return { ...prevState,
        setPassword: { ...prevState.setPassword,
          verifyResetCodeTransit: (0, _TransitState.transitSuccess)(action.payload.transitId)
        }
      };

    case 'Authentication/VerifyResetCode/Failed':
      if (prevState.setPassword.verifyResetCodeTransit.transitId !== action.payload.transitId) {
        return prevState;
      }

      return { ...prevState,
        setPassword: { ...prevState.setPassword,
          verifyResetCodeTransit: (0, _TransitState.transitFailed)(action.payload.errorMessage, action.payload.transitId)
        }
      };
    // Set password (after a "forgot password" request and verifying a code)

    case 'Authentication/SetPassword/Reset':
      return { ...prevState,
        setPassword: { ...prevState.setPassword,
          setPasswordTransit: _TransitState.initialTransitState
        }
      };

    case 'Authentication/SetPassword/Started':
      return { ...prevState,
        setPassword: { ...prevState.setPassword,
          setPasswordTransit: (0, _TransitState.transitStart)(action.payload.transitId)
        }
      };

    case 'Authentication/SetPassword/Succeeded':
      if (prevState.setPassword.setPasswordTransit.transitId !== action.payload.transitId) {
        return prevState;
      }

      return { ...prevState,
        setPassword: { ...prevState.setPassword,
          setPasswordTransit: (0, _TransitState.transitSuccess)(action.payload.transitId)
        }
      };

    case 'Authentication/SetPassword/Failed':
      if (prevState.setPassword.setPasswordTransit.transitId !== action.payload.transitId) {
        return prevState;
      }

      return { ...prevState,
        setPassword: { ...prevState.setPassword,
          setPasswordTransit: (0, _TransitState.transitFailed)(action.payload.errorMessage, action.payload.transitId)
        }
      };

    default:
      return prevState;
  }
};

exports.defaultAccountUIReducer = defaultAccountUIReducer;
//# sourceMappingURL=reducer.js.map