"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  useRegistrationUIState: true,
  useRegistrationUIActions: true,
  RegistrationStateContext: true,
  RegistrationActionContext: true,
  RegistrationActionsCreator: true,
  RegistrationActions: true
};
Object.defineProperty(exports, "RegistrationActionContext", {
  enumerable: true,
  get: function () {
    return _context.RegistrationActionContext;
  }
});
Object.defineProperty(exports, "RegistrationActions", {
  enumerable: true,
  get: function () {
    return _dispatchActions.RegistrationActions;
  }
});
Object.defineProperty(exports, "RegistrationActionsCreator", {
  enumerable: true,
  get: function () {
    return _actions.RegistrationActionsCreator;
  }
});
Object.defineProperty(exports, "RegistrationStateContext", {
  enumerable: true,
  get: function () {
    return _context.RegistrationStateContext;
  }
});
exports.useRegistrationUIState = exports.useRegistrationUIActions = void 0;

var _react = require("react");

var _context = require("./context");

var _types = require("./types");

Object.keys(_types).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _types[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types[key];
    }
  });
});

var _reducer = require("./reducer");

Object.keys(_reducer).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _reducer[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _reducer[key];
    }
  });
});

var _actions = require("./actions");

var _dispatchActions = require("./dispatchActions");

/**
 * RegistrationStateContext and RegistrationActionContext provide access to global state and actions for registration related information (load EULA, complete registration, etc.).
 *
 * @packageDocumentation
 * @module RegistrationUIContext
 * @internal
 * @preferred
 */

/**
 * Hook for using the global account state for account-related global [[RegistrationUIState]] state changes (i.e. loading EULA, registration via invite).
 *
 * @category Hooks
 */
const useRegistrationUIState = () => {
  const context = (0, _react.useContext)(_context.RegistrationStateContext);

  if (context === null) {
    throw new Error('useRegistrationUIState must be used within an RegistrationUIContext');
  }

  return context;
};
/**
 * Hook for using the global [[RegistrationUIActions]] actions (i.e. loadEULA, completeRegistration, etc.) which change the global [[RegistrationUIState]].
 *
 * @category Hooks
 */


exports.useRegistrationUIState = useRegistrationUIState;

const useRegistrationUIActions = () => {
  const context = (0, _react.useContext)(_context.RegistrationActionContext);

  if (context === null) {
    throw new Error('useRegistrationUIActions must be used within an RegistrationUIContext');
  }

  return context;
};

exports.useRegistrationUIActions = useRegistrationUIActions;
//# sourceMappingURL=index.js.map